@@ -109,6 +109,14 @@ QVariant OutputModel::data(const QModelIndex &index, int role) const
         return m_outputs[index.row()].moving;
     case IccProfileRole:
         return output->iccProfilePath();
+    case HdrRole:
+        return output->isHdrEnabled() && output->isWcgEnabled();
+    case SdrBrightnessRole:
+        return output->sdrBrightness();
+    case MaxBrightnessRole:
+        return output->maxPeakBrightnessOverride().value_or(output->maxPeakBrightness());
+    case SdrGamutWideness:
+        return output->sdrGamutWideness();
     }
     return QVariant();
 }
@@ -254,6 +262,19 @@ bool OutputModel::setData(const QModelIndex &index, const QVariant &value, int r
         m_outputs[index.row()].ptr->setIccProfilePath(value.toString());
         Q_EMIT dataChanged(index, index, {role});
         return true;
+    case HdrRole:
+        output.ptr->setHdrEnabled(value.toBool());
+        output.ptr->setWcgEnabled(value.toBool());
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
+    case SdrBrightnessRole:
+        output.ptr->setSdrBrightness(value.toUInt());
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
+    case SdrGamutWideness:
+        output.ptr->setSdrGamutWideness(value.toDouble());
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
     }
     return false;
 }
@@ -284,6 +305,10 @@ QHash<int, QByteArray> OutputModel::roleNames() const
     roles[RgbRangeRole] = "rgbRange";
     roles[InteractiveMoveRole] = "interactiveMove";
     roles[IccProfileRole] = "iccProfilePath";
+    roles[HdrRole] = "hdr";
+    roles[SdrBrightnessRole] = "sdrBrightness";
+    roles[MaxBrightnessRole] = "peakBrightness";
+    roles[SdrGamutWideness] = "sdrGamutWideness";
     return roles;
 }
 
